#!/usr/bin/python
# -*- coding: utf-8 -*-¬
from flask import request, jsonify
import requests
from functools import wraps


def token_required(func):
    # token验证装饰器
    @wraps(func)
    def decorator(*args, **kwargs):
        if request.method == 'GET':
            grant_type = request.args.get('grant_type')
            auth_token = request.args.get('auth_token')
            key_url = 'http://127.0.0.1:5001/hs_auth/app_verify_token/'
            json_params = {'grant_type': grant_type, 'auth_token': auth_token, 'app_id': ''}
            res = requests.post(url=key_url, json=json_params,
                                headers={"Content-type": "application/json", "Accept": "*/*"})
            if res.text:
                return res.text
            return func(*args, **kwargs)
        raise RuntimeError('Verify failed')

    return decorator



from distutils.core import setup
from setuptools import find_packages

setup(name='HSAuth',  # 包名
      version='1.0.0',  # 版本号
      description='',
      long_description='',
      author='',
      author_email='',
      url='https://gitlab.com/zmbgitlab',
      license='',
      install_requires=['Flask', 'requests'],
      classifiers=[
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Natural Language :: Chinese (Simplified)',
          'Programming Language :: Python :: 3.5',
          'Topic :: Utilities'
      ],
      keywords='',
      packages=find_packages('src'),  # 必填
      package_dir={'': 'src'},  # 必填
      include_package_data=True,
      )
